import React, { useState } from 'react'
import styled from '@emotion/styled/macro'


const DropDownMenu = styled.div`
  position: relative;

  &:hover {
    cursor: pointer;
  }

  width: fit-content;
  display: inline-block;
`

const DropDownList = styled.ul`
  position: absolute;
  right: 1rem;
  top: 2rem;
  border-radius: 1rem;
  list-style-type: none;
  min-width: 10rem;
  max-height: 50rem;
  z-index: 100;
`

interface IDropDownOption {
  name: string;
  value: any;
}

const getValueName = (value: any, options: Array<IDropDownOption>): string => {
  for (let i = 0; i < options.length; i += 1) {
    if (options[i].value === value) {
      return options[i].name
    }
  }
  return ''
}

interface IProps {
  options: any[];
  placeholder?: string;
  value: any;
  onChange: (event: any) => void;
}


function DropDown(props: IProps) {
  const [open, setOpen] = useState(false)

  const {
    options,
    placeholder,
    value,
    onChange,
  } = props

  function handleClick(option: any) {
    setOpen(!open)
    onChange(option.value)
  }

  function openMenu() {
    if (!open) {
      setOpen(true)
    }
  }

  return (

    <DropDownMenu
      aria-haspopup='true'
      aria-expanded={open}
      /* eslint-disable-next-line react/jsx-no-bind */
      onFocus={openMenu}
      tabIndex={0}
    >
      <div>
        <div role='button'
             onKeyDown={(event) => {
               if (event.key === 'Enter' || event.key === ' ') {
                 openMenu()
               }
             }}
             onClick={openMenu}
             tabIndex={0}
        >
          {/* eslint-disable-next-line */}
          {placeholder
            ? placeholder
            : getValueName(value, options).toLowerCase()}
        </div>
      </div>
      <div>
        {open && (
          <DropDownList>
            {options.map((option) => (
              // eslint-disable-next-line jsx-a11y/no-noninteractive-element-interactions
              <li
                onKeyDown={(event) => {
                  if (event.key === 'Enter' || event.key === ' ') {
                    openMenu()
                  }
                }}

                onClick={(
                  // eslint-disable-next-line @typescript-eslint/no-unused-vars
                  event: React.MouseEvent<HTMLElement, MouseEvent>,
                ) => {
                  handleClick(option)
                }}
              >
                <p>{option.name}</p>
              </li>
            ))}
          </DropDownList>
        )}
      </div>
    </DropDownMenu>
  )
}


DropDown.defaultProps =
  {
    placeholder: undefined,
  }

export default DropDown
