import React from 'react'
import { Helmet } from 'react-helmet'
import { useTranslation } from 'react-i18next'

import { styled } from '@mui/material/styles'
import { Container } from '@mui/material'

const StyledPageHeader = styled('h2')(({ theme }) => ({
  color: theme.greg.headerTextColor,
  fontSize: '3rem',
  fontWeight: 'bold',
  margin: '0 6.5rem 0 6.5rem',
}))

interface IPage {
  children: React.ReactNode
  header?: string
}

export default function Page(props: IPage) {
  const { header, children } = props
  const { i18n, t } = useTranslation()
  const appTitle = t('common:header:applicationTitle')

  return (
    <>
      <Helmet titleTemplate={`%s - ${appTitle}`} defaultTitle={appTitle}>
        <html lang={i18n.language} />
        <title>{header}</title>
      </Helmet>
      <Container>
        <StyledPageHeader>{header}</StyledPageHeader>
        {children}
      </Container>
    </>
  )
}

Page.defaultProps = {
  header: null,
}
